@@ -1,6 +1,8 @@
 extern struct event_loop g_event_loop;
 extern int g_connection;
 
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wunused-parameter"
 static DISPLAY_EVENT_HANDLER(display_handler)
 {
     if (flags & kCGDisplayAddFlag) {
@@ -13,6 +15,7 @@ static DISPLAY_EVENT_HANDLER(display_handler)
         event_loop_post(&g_event_loop, DISPLAY_RESIZED, (void *)(intptr_t) did, 0);
     }
 }
+#pragma clang diagnostic pop
 
 void display_serialize(FILE *rsp, uint32_t did, uint64_t flags)
 {
@@ -117,19 +120,21 @@ uint32_t display_id(CFStringRef uuid)
     return did;
 }
 
-CGRect display_bounds_constrained(uint32_t did)
+CGRect display_bounds_constrained(uint32_t did, bool ignore_external_bar)
 {
     CGRect frame = CGDisplayBounds(did);
     int effective_ext_top_padding = 0;
 
-    if ((g_display_manager.mode == EXTERNAL_BAR_MAIN &&
-         did == display_manager_main_display_id()) ||
-        (g_display_manager.mode == EXTERNAL_BAR_ALL)) {
-        effective_ext_top_padding = g_display_manager.top_padding;
+    if (!ignore_external_bar) {
+        if ((g_display_manager.mode == EXTERNAL_BAR_MAIN &&
+             did == display_manager_main_display_id()) ||
+            (g_display_manager.mode == EXTERNAL_BAR_ALL)) {
+            effective_ext_top_padding = g_display_manager.top_padding;
 
-        frame.origin.y    += effective_ext_top_padding;
-        frame.size.height -= effective_ext_top_padding;
-        frame.size.height -= g_display_manager.bottom_padding;
+            frame.origin.y    += effective_ext_top_padding;
+            frame.size.height -= effective_ext_top_padding;
+            frame.size.height -= g_display_manager.bottom_padding;
+        }
     }
 
     if (display_manager_menu_bar_hidden()) {
