@@ -3,6 +3,7 @@ typedef CONNECTION_CALLBACK(connection_callback);
 
 static mach_port_t (* CGSGetConnectionPortById)(int);
 extern mach_port_t mig_get_special_reply_port(void);
+extern AXUIElementRef _AXUIElementCreateWithRemoteToken(CFDataRef data);
 extern AXError _AXUIElementGetWindow(AXUIElementRef ref, uint32_t *wid);
 extern int SLSMainConnectionID(void);
 extern CGError SLSNewConnection(int zero, int *cid);
@@ -68,7 +69,7 @@ extern uint32_t SLSWindowIteratorGetParentID(CFTypeRef iterator);
 extern uint32_t SLSWindowIteratorGetWindowID(CFTypeRef iterator);
 extern uint64_t SLSWindowIteratorGetTags(CFTypeRef iterator);
 extern uint64_t SLSWindowIteratorGetAttributes(CFTypeRef iterator);
-extern int SLSWindowIteratorGetLevel(CFTypeRef iterator, int32_t index);
+extern int SLSWindowIteratorGetLevel(CFTypeRef iterator);
 extern OSStatus _SLPSGetFrontProcess(ProcessSerialNumber *psn);
 extern CGError SLSGetWindowOwner(int cid, uint32_t wid, int *wcid);
 extern CGError SLSGetConnectionPSN(int cid, ProcessSerialNumber *psn);
