@@ -4,52 +4,39 @@
 #define AX_ABS(a, b) (((a) - (b) < 0) ? (((a) - (b)) * -1) : ((a) - (b)))
 #define AX_DIFF(a, b) (AX_ABS(a, b) >= 1.5f)
 
+#define SPACE_PROPERTY_LIST \
+    SPACE_PROPERTY_ENTRY("id",                   SPACE_PROPERTY_ID,            0x001) \
+    SPACE_PROPERTY_ENTRY("uuid",                 SPACE_PROPERTY_UUID,          0x002) \
+    SPACE_PROPERTY_ENTRY("index",                SPACE_PROPERTY_INDEX,         0x004) \
+    SPACE_PROPERTY_ENTRY("label",                SPACE_PROPERTY_LABEL,         0x008) \
+    SPACE_PROPERTY_ENTRY("type",                 SPACE_PROPERTY_TYPE,          0x010) \
+    SPACE_PROPERTY_ENTRY("display",              SPACE_PROPERTY_DISPLAY,       0x020) \
+    SPACE_PROPERTY_ENTRY("windows",              SPACE_PROPERTY_WINDOWS,       0x040) \
+    SPACE_PROPERTY_ENTRY("first-window",         SPACE_PROPERTY_FIRST_WINDOW,  0x080) \
+    SPACE_PROPERTY_ENTRY("last-window",          SPACE_PROPERTY_LAST_WINDOW,   0x100) \
+    SPACE_PROPERTY_ENTRY("has-focus",            SPACE_PROPERTY_HAS_FOCUS,     0x200) \
+    SPACE_PROPERTY_ENTRY("is-visible",           SPACE_PROPERTY_IS_VISIBLE,    0x400) \
+    SPACE_PROPERTY_ENTRY("is-native-fullscreen", SPACE_PROPERTY_IS_FULLSCREEN, 0x800)
+
 enum space_property
 {
-    SPACE_PROPERTY_ID            = 0x001,
-    SPACE_PROPERTY_UUID          = 0x002,
-    SPACE_PROPERTY_INDEX         = 0x004,
-    SPACE_PROPERTY_LABEL         = 0x008,
-    SPACE_PROPERTY_TYPE          = 0x010,
-    SPACE_PROPERTY_DISPLAY       = 0x020,
-    SPACE_PROPERTY_WINDOWS       = 0x040,
-    SPACE_PROPERTY_FIRST_WINDOW  = 0x080,
-    SPACE_PROPERTY_LAST_WINDOW   = 0x100,
-    SPACE_PROPERTY_HAS_FOCUS     = 0x200,
-    SPACE_PROPERTY_IS_VISIBLE    = 0x400,
-    SPACE_PROPERTY_IS_FULLSCREEN = 0x800
+#define SPACE_PROPERTY_ENTRY(n, p, v) p = v,
+    SPACE_PROPERTY_LIST
+#undef SPACE_PROPERTY_ENTRY
 };
 
 static uint64_t space_property_val[] =
 {
-    [0x0] = SPACE_PROPERTY_ID,
-    [0x1] = SPACE_PROPERTY_UUID,
-    [0x2] = SPACE_PROPERTY_INDEX,
-    [0x3] = SPACE_PROPERTY_LABEL,
-    [0x4] = SPACE_PROPERTY_TYPE,
-    [0x5] = SPACE_PROPERTY_DISPLAY,
-    [0x6] = SPACE_PROPERTY_WINDOWS,
-    [0x7] = SPACE_PROPERTY_FIRST_WINDOW,
-    [0x8] = SPACE_PROPERTY_LAST_WINDOW,
-    [0x9] = SPACE_PROPERTY_HAS_FOCUS,
-    [0xA] = SPACE_PROPERTY_IS_VISIBLE,
-    [0xB] = SPACE_PROPERTY_IS_FULLSCREEN
+#define SPACE_PROPERTY_ENTRY(n, p, v) p,
+    SPACE_PROPERTY_LIST
+#undef SPACE_PROPERTY_ENTRY
 };
 
 static char *space_property_str[] =
 {
-    "id",
-    "uuid",
-    "index",
-    "label",
-    "type",
-    "display",
-    "windows",
-    "first-window",
-    "last-window",
-    "has-focus",
-    "is-visible",
-    "is-native-fullscreen"
+#define SPACE_PROPERTY_ENTRY(n, p, v) n,
+    SPACE_PROPERTY_LIST
+#undef SPACE_PROPERTY_ENTRY
 };
 
 struct area
@@ -104,6 +91,20 @@ struct balance_node
     int x_count;
 };
 
+enum window_insertion_point
+{
+    INSERT_FOCUSED,
+    INSERT_FIRST,
+    INSERT_LAST
+};
+
+static const char *window_insertion_point_str[] =
+{
+    "focused",
+    "first",
+    "last"
+};
+
 enum window_node_child
 {
     CHILD_NONE,
@@ -187,6 +188,7 @@ enum view_flag
     VIEW_ENABLE_GAP     = 0x100,
     VIEW_IS_VALID       = 0x200,
     VIEW_IS_DIRTY       = 0x400,
+    VIEW_SPLIT_TYPE     = 0x800,
 };
 
 struct view
@@ -196,12 +198,13 @@ struct view
     struct window_node *root;
     uint32_t insertion_point;
     enum view_type layout;
+    enum window_node_split split_type;
     int top_padding;
     int bottom_padding;
     int left_padding;
     int right_padding;
     int window_gap;
-    bool auto_balance;
+    uint32_t auto_balance;
     uint64_t flags;
 };
 
@@ -237,6 +240,7 @@ bool view_is_dirty(struct view *view);
 void view_flush(struct view *view);
 void view_update(struct view *view);
 struct view *view_create(uint64_t sid);
+void view_destroy(struct view *view);
 void view_clear(struct view *view);
 
 #endif
