@@ -899,7 +899,9 @@ int window_level(uint32_t wid)
         if (!iterator) goto err1;
 
         if (SLSWindowIteratorGetCount(iterator) == 1) {
-            level = SLSWindowIteratorGetLevel(iterator, 0);
+            if (SLSWindowIteratorAdvance(iterator)) {
+                level = SLSWindowIteratorGetLevel(iterator);
+            }
         }
 
         CFRelease(iterator);
@@ -1112,10 +1114,3 @@ void window_destroy(struct window *window)
     CFRelease(window->ref);
     free(window);
 }
-
-void window_dump_cg_window_levels(void)
-{
-    for (int i = 0; i < CG_WINDOW_LEVEL_KEY_COUNT; ++i) {
-        printf("CGWindowLevelForKey(%s) -> %d\n", cg_window_level_key_str[i], CGWindowLevelForKey(i));
-    }
-}
